#!/usr/bin/env seed
// Returns: 0
// STDIN:
// STDOUT:Hello World!\n\[undefined\]
// STDERR:

print(print("Hello World!"));
